-- Class for creating a displayable playing card
-- for sake of simplicity, cards are currently a fixed size of 60x100 but that should be fairly easy to change in the future

-- to create a card, simply assign it a back image, front image, suit icon and number
-- to display the card, set it's position, facing (defaults to face down) and rotation (optional), then set it visible

Card=class(Turbine.UI.Window);

-- declare the Facing constants
if GaranStuff.Cards.FaceDown==nil then GaranStuff.Cards.FaceDown=0 end;
if GaranStuff.Cards.FaceUp==nil then GaranStuff.Cards.FaceUp=1 end;

function Card:Constructor()
	Turbine.UI.Window.Constructor(self);
	self.Rotation={x=0,y=0,z=0}; -- we track rotation since hiding and redisplaying a window resets the rotation so we override that
	self.Suit=0;
	self.Number=nil;
	self.SuitIconImage="";
	self.FaceImage="";
	self.BackImage="";
	self.Facing=0; -- 0=face down, 1=face up
	self.ShowSuitIcon=true;
	self.ShowNumber=true;
	self:SetSize(100,100); -- size the cards with 3x3 border

	self.Image=Turbine.UI.Control();
	self.Image:SetParent(self);
	self.Image:SetPosition(0,0);
	self.Image:SetSize(60,100);
	self.Image:SetMouseVisible(false);

	self.NumberText=Turbine.UI.Label();
	self.NumberText:SetParent(self.Image);
	self.NumberText:SetSize(20,20);
	self.NumberText:SetPosition(35,3);
	self.NumberText:SetFont(Turbine.UI.Lotro.Font.Verdana20);
	self.NumberText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
	self.NumberText:SetForeColor(Turbine.UI.Color(1,1,1));
	self.NumberText:SetOutlineColor(Turbine.UI.Color(0,0,0));
	self.NumberText:SetFontStyle(Turbine.UI.FontStyle.Outline);
	self.NumberText:SetText("");
	self.NumberText:SetMouseVisible(false);
	self.NumberText2=Turbine.UI.Label();
	self.NumberText2:SetParent(self.Image);
	self.NumberText2:SetSize(20,20);
	self.NumberText2:SetPosition(5,77);
	self.NumberText2:SetFont(Turbine.UI.Lotro.Font.Verdana20);
	self.NumberText2:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.NumberText2:SetForeColor(Turbine.UI.Color(1,1,1));
	self.NumberText2:SetOutlineColor(Turbine.UI.Color(0,0,0));
	self.NumberText2:SetFontStyle(Turbine.UI.FontStyle.Outline);
	self.NumberText2:SetText("");
	self.NumberText2:SetMouseVisible(false);

	self.SuitIcon=Turbine.UI.Control();
	self.SuitIcon:SetParent(self.Image);
	self.SuitIcon:SetPosition(5,5);
	self.SuitIcon:SetSize(16,16);
	self.SuitIcon:SetMouseVisible(false);
	self.SuitIcon:SetBlendMode(Turbine.UI.BlendMode.Overlay);
	self.SuitIcon2=Turbine.UI.Control();
	self.SuitIcon2:SetParent(self.Image);
	self.SuitIcon2:SetPosition(39,79);
	self.SuitIcon2:SetSize(16,16);
	self.SuitIcon2:SetMouseVisible(false);
	self.SuitIcon2:SetBlendMode(Turbine.UI.BlendMode.Overlay);

	self.Border=Turbine.UI.Control();
	self.Border:SetParent(self.Image);
	self.Border:SetSize(60,100);
	self.Border:SetMouseVisible(false);
	self.Border:SetVisible(false);
	self.Border:SetBackground("GaranStuff/Cards/Resources/Highlight.tga");
	self.Border:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);

	self.GetRotation=function(sender)
		return self.Rotation;
	end

	self.SetRotation=function(sender, rotation)
		-- override the built-in SetRotation so that we can track the rotation value
		self.Rotation=rotation;
		if self:IsVisible() then
			Turbine.UI.Window.SetRotation(self,self.Rotation);
		end
	end
	self.SetVisible=function(sender, visible)
		Turbine.UI.Window.SetVisible(self,visible);
		if self:IsVisible() then
			if self.Rotation.z~=0 then
				Turbine.UI.Window.SetRotation(self,self.Rotation);
			end
		end
	end
	self.GetFacing=function(sender)
		return self.Facing;
	end
	self.SetFacing=function(sender,facing)
		sender.Facing=facing;
		if sender.Facing==GaranStuff.Cards.FaceUp then
			if sender.ShowSuitIcon and sender.SuitIconImage~="" and sender.SuitIconImage~=nil then
				sender.SuitIcon:SetBackground(sender.SuitIconImage);
				sender.SuitIcon:SetVisible(true);
				sender.SuitIcon2:SetBackground(sender.SuitIconImage);
				sender.SuitIcon2:SetVisible(true);
			else
				sender.SuitIcon:SetVisible(false);
				sender.SuitIcon2:SetVisible(false);
			end
			if sender.ShowNumber and sender.Number~=nil then
				sender.NumberText:SetText(sender.Number);
				sender.NumberText:SetVisible(true);
				sender.NumberText2:SetText(sender.Number);
				sender.NumberText2:SetVisible(true);
			else
				sender.NumberText:SetVisible(false);
				sender.NumberText2:SetVisible(false);
			end
			if sender.FaceImage~="" and sender.FaceImage~=nil then
				sender.Image:SetBackground(sender.FaceImage);
			else
				sender.Image:SetBackground(0); -- need to come up with a better default...
			end
		else
			sender.SuitIcon:SetVisible(false);
			sender.SuitIcon2:SetVisible(false);
			sender.NumberText:SetVisible(false);
			sender.NumberText2:SetVisible(false);
			if sender.BackImage~="" and sender.BackImage~=nil then
				sender.Image:SetBackground(sender.BackImage);
			else
				sender.Image:SetBackground(0);
			end
		end
	end
end
